#-------------------------------------------------------------------------------
# @(#) huawei-nss/V33/EngineConfig.pm huawei-nss_r3.3.0.latest:cset.003248:5:5@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# 
# Copyright (c) 2007 IBM Tivoli Software Systems. All rights reserved.

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();
use AudLog;

#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = 
    (
    	## Process Multi-lined object names ...
         {
         RULE_TYPE => 'Generic_ASCII',
         RULE_DESC => 'HUAWEI NSS V33 DATA',
         INPUT_FILE_DESCRIPTION => [ 
				'^\w+_COMBCDOTM1_\w+_\d{8}\.TXT$' ,
				'^\w+_COMBCDOTM2_\w+_\d{8}\.TXT$', 
				'^\w+_HOMOCELL_\w+_\d{8}\.TXT$', 
				'^\w+_SRFRM\w+_\d{8}\.TXT$',
				],
         INPUT_DIR_DEPTH => 0,
         ORDER_OF_FILES => 'OLDEST_FIRST',

	 	OUTPUT_BLOCK_NAME          => 'HUAWEI_NSS',
	 	DEFAULT_NULL_VALUE         => '',
	 	UPPERCASE_COUNTERS         => 0,
	 	FILENAME_HEADER_FIELDS      => {
			FILENAME	=> '(.*)',
			ORIGINAL_FILENAME	=> '(.*)',
			MSC_NAME	=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
			NODEID		=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
			MSC_ID		=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
			BLOCKNAME	=> '^[A-Za-z0-9]+_(\w+)_\d{8}\.TXT$',
	 	},

	 	HEADER_INFO_TO_KEY_PIF_FILENAME => ['FILENAME'],
                EOF_LINE			=> 'EOF',  
         HEADER_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\=+
*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				
				%$d_href = ();
				
				delete $rule_obj->{COUNTER_NAMES};
      			delete $rule_obj->{CJ_TIMESTAMP};
				if ($rule_obj->{OLD_FILENAME} ne $h_href->{ORIGINAL_FILENAME}) {
					$rule_obj->{OLD_FILENAME} = $h_href->{ORIGINAL_FILENAME};
					$rule_obj->{BLOCK_COUNTER} = 0;
				}
				$rule_obj->{BLOCK_COUNTER}++;	
				$h_href->{FILENAME} = $h_href->{ORIGINAL_FILENAME} . "_PART_" . $rule_obj->{BLOCK_COUNTER};
				return 'NEXTLINE';
			},
		},
		
		{
			LINE_DESCRIPTION => '^\d{4}-\d{2}-\d{2}\ \d{2}:\d{2}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				shift @{$rule_obj->{COUNTER_NAMES}};
				
				$rule_obj->{CJ_FLAG} = 'True';
				return 'GODATA';
			},
		},
		
		{
			LINE_DESCRIPTION => '^(.*\|){2,}',   ## check for lines starting with Calling:(ambiguous) and Module No
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			    my $line = $$line_sref;					
				
			    chomp $line;    

				if (exists ($rule_obj->{COUNTER_NAMES})) {
					
					my @temp_array_1 = split /\|/, $line;

					my $numElements = scalar(@temp_array_1);

					my $array1Index;
					
					for($array1Index=0; $array1Index < $numElements; $array1Index++) {
						$temp_array_1[$array1Index] =~ s/ $//;
					}
						
					
					my @temp_array_2 = @{$rule_obj->{COUNTER_NAMES}};
					my @new_countername;
					foreach my $item (@temp_array_2) {
						my $temp_name = shift @{$rule_obj->{COUNTER_NAMES}} ;
						
						$temp_name .= shift @temp_array_1;
						
						push @new_countername, $temp_name;
					}

					my $counterNameIndex;
					for($counterNameIndex=0; $counterNameIndex<scalar(@new_countername); $counterNameIndex++) {
						
						$new_countername[$counterNameIndex] =~ s/ *
//g;

						$new_countername[$counterNameIndex] =~ s/ /_/g;
						
					}
					
					$rule_obj->{COUNTER_NAMES} = \@new_countername;
				}
				else {
					my @temp = split /\|/, $line;
					$rule_obj->{COUNTER_NAMES} = \@temp;
					
					my $array1Index;
					my $numElements = scalar(@temp);
					
					for($array1Index=0; $array1Index < $numElements; $array1Index++) {
						$temp[$array1Index] =~ s/ $//;
					}

				}
				return 'NEXTLINE';
			},
		},
	 ],   ## end HEADER_LINE_PROCESSING ...
	 
	 
	 
	 	DATA_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\=+
*$',
			LINE_PROCESSING  => sub {
				return 'GOHEADER';
			},
		},
		
		
	 	{
			LINE_DESCRIPTION => '^\d{4}-\d{2}-\d{2}\ \d{2}:\d{2}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			    my $line = $$line_sref;

				if (exists($rule_obj->{CJ_TIMESTAMP}))
				{	
					($d_href->{START_DATE}, $d_href->{START_TIME}, my $discard,$d_href->{GP}) = split /\ /, $rule_obj->{CJ_TIMESTAMP}; 
					$d_href->{GP} *= 60;
				    $rule_obj->{CJ_TIMESTAMP} = $$line_sref;
					$rule_obj->{CJ_FLAG} = 'True';
					

				    foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
						$d_href->{$counter_name} = shift @{$rule_obj->{COUNTER_VALUES}};
					}	
					$d_href->{Object_Name} = $rule_obj->{OBJECT_NAMES};
					return 'WRITEPIF';
				}
				else {
                    $rule_obj->{CJ_TIMESTAMP} = $$line_sref;
					return 'NEXTLINE';
				}

			},
		},
		
		
	 	{
			
		      	LINE_DESCRIPTION => '^Calling:\(ambiguous\)(.*)|^Module\sNo.:(\d+)(.*)|^Observed\scell\:(\w+)\,\sadjac',   ## reading object part  
				#LINE_DESCRIPTION => '^Module\sNo\..*',   ## reading object part  
	        	#LINE_DESCRIPTION => '^Calling:\(ambiguous\)(.*)',	
				LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			    my $line = $$line_sref;

			    ## objects..
				$line =~ s/\ +\|/|/g;
				
				$line =~ s/
//g;
				
				$line =~ s/^\ *//g;
				
				$line =~ tr/\n\t -~//cd;
				
				$line =~ s/\ *
*$//g;
				
				$line =~ s/\ *\=\ */\=/g;
				
				$line =~ s/\ *\,\ */\,/g;
				
				$line =~ s/(\d+)\,(\d+)/$1\.$2/g;
				
				$line =~ s/(\d+)\%/$1/g;
				
				$line =~ s/\ /_/g;
				
				
				$line =~ s/\-/_/g;
				
				
				$line =~ s/\_\_+//g;
				
				
				$line =~ s/\<NULL\>//g;
				
				$line =~ s/\*//g;

				
			        if ($rule_obj->{CJ_FLAG} eq 'False'){
				
					foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
						$d_href->{$counter_name} = shift @{$rule_obj->{COUNTER_VALUES}};
					}
					
					$d_href->{Object_Name} = $rule_obj->{OBJECT_NAMES};
			
					# Ready for PIF write, now read in current line

					my @temparray = split /\|/, $line;
					my $i;
					my $arrayLen = scalar(@temparray); #get object names and also counter values within a line

					$rule_obj->{OBJECT_NAMES} = shift @temparray;

					$rule_obj->{COUNTER_VALUES} = \@temparray;					

			        ($d_href->{START_DATE}, $d_href->{START_TIME}, my $discard,$d_href->{GP}) = split /\ /, $rule_obj->{CJ_TIMESTAMP};
					$d_href->{GP} *= 60;

					return 'WRITEPIF'; 
					#handle the partial object name at each line. 
					#handle the counter values based on this partial object name at a particular line.
					#b4 writting the complete object name, put it into d_href{} 1st from the $rule_object->{OBJECT_NAME}
				
				}
				else {
					$rule_obj->{CJ_FLAG} = 'False';
					@{$rule_obj->{COUNTER_VALUES}} = split /\|/, $line;
					my @temparray = split /\|/, $line;
					
					$rule_obj->{OBJECT_NAMES} = shift @temparray;
					$rule_obj->{COUNTER_VALUES} = \@temparray;
					

					return 'NEXTLINE';
				}	
			     
		}
	},
	
		{
             LINE_DESCRIPTION=>'^EOF',
             LINE_PROCESSING  => sub {
	         	my ($rule_obj, $line_sref, $h_href, $d_href) = @_;          
				foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
					$d_href->{$counter_name} = shift @{$rule_obj->{COUNTER_VALUES}};
				}
		
				$d_href->{Object_Name} = $rule_obj->{OBJECT_NAMES};
		    	($d_href->{START_DATE}, $d_href->{START_TIME}, my $discard,$d_href->{GP}) = split /\ /, $rule_obj->{CJ_TIMESTAMP};
	            return 'WRITEPIF';
			 },    
		},	
	
		
		{
			LINE_DESCRIPTION => '^.*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			    my $line = $$line_sref;
			         
				$line =~ s/\ +\|/|/g;
				
				$line =~ s/
//g;
				
				$line =~ s/^\ *//g;
				
				$line =~ tr/\n\t -~//cd;
				
				$line =~ s/\ *
*$//g;
				
				$line =~ s/\ *\=\ */\=/g;
				
				$line =~ s/\ *\,\ */\,/g;
				
				$line =~ s/(\d+)\,(\d+)/$1\.$2/g;
				
				$line =~ s/(\d+)\%/$1/g;
				
				$line =~ s/\ /_/g;
				
				$line =~ s/\//_/g;	
				
				
				$line =~ s/\-/_/g;
				
				
				$line =~ s/\_\_+//g;
				
				
				$line =~ s/\<NULL\>//g;
				
				$line =~ s/\*//g;
				
                my @new_objectName;
				my @temp_array_1 = split /\|/, $line;				
				
				my @temp_array_2 = @{$rule_obj->{COUNTER_VALUES}};
				$rule_obj->{OBJECT_NAMES} .= shift @temp_array_1;
				
				foreach my $item (@temp_array_2) {

		            my $temp_name = shift @{$rule_obj->{COUNTER_VALUES}};
		            $temp_name .= shift @temp_array_1;

		            push @new_objectName, $temp_name;
				}

				$rule_obj->{COUNTER_VALUES} = \@new_objectName;
				
				return 'NEXTLINE';
			},
	},
	],

	 HEADER_DATA_RECORD_PROCESSING => sub {
		my ($blk_name_ref, $h_ref, $d_ref) = @_;
	
		$h_ref->{BLOCKNAME} =~ s/\_REPORT//g;
		$$blk_name_ref = $h_ref->{BLOCKNAME};

		# Format the counters to remove extra underscores
		foreach my $cname_ori (keys %$d_ref) {
			my $cname_new = $cname_ori;
			
			
			$cname_new =~ s/\-/_/g;
			
			
			$cname_new =~ s/_{2,}/_/g;
			
			
			
			$cname_new =~ s/\_+$//g;
			$cname_new =~ s/\_+/\_/g;
			$cname_new =~ s/\(//g;
			$cname_new =~ s/\)//g;
			
			
			## remove forward slash
			$cname_new =~ s/\//\_/g;
			## remove commas
			$cname_new =~ s/\,//g;
			##remove ampersand
			$cname_new =~ s/\&//g;
			##replace space with NULL
			$cname_new =~ s/\s+//g;

			
			$d_ref->{$cname_new} = $d_ref->{$cname_ori};
			
			delete $d_ref->{$cname_ori} if $cname_new ne $cname_ori;
		}

		my $id_name;
		my $id_value;
		# Split up Objects
		if (exists($d_ref->{Object_Name})){
			
			my @object_name = split /\,/, $d_ref->{Object_Name};
			my $oname_ori;
			my $MMC_MNC;
			my $LAC;
			 
			foreach $oname_ori (@object_name) {
				
				#if ($oname_ori =~ /(.*)\:(.*)/) {
				if($oname_ori =~ /(\w+?\s*\w*\.{0,})\:(.*)/ ){
					if ($oname_ori =~ /^Observed_cell\:(\d{5})([a-zA-z0-9]{4})(.*)/ ) {
						$d_ref->{Observed_cell} = sprintf("%05d", hex($3));
						$MMC_MNC	= $1;
						$LAC		= $2;
						
					}
					elsif ($oname_ori =~ /^adjacent_cell\:(\d{5})([a-zA-z0-9]{4})(.*)/ ) {
						$d_ref->{adjacent_cell} = sprintf("%05d", hex($3));
						$MMC_MNC	= $1;
						$LAC		= $2;
					}
					else{
						$id_name = $1;
						$id_value = $2;
						$id_name =~ s/\.//g;
					}

					$d_ref->{$id_name} = $id_value;
				} 
				else{
					$id_value  = $oname_ori;
					$id_name   = "Call_Type";
					$d_ref->{$id_name} = $id_value;
				}
		
				if($id_value =~ /\s+/ || $id_value =~ /_/  || $id_value =~/^\(/ || $id_value =~/^\)/ ){	
				
					$id_value =~s /_/ /g;
					
					$id_value =~ s/^\(//g;
					$id_value =~ s/\)$//g;
					
					$id_value =~ s/^/\"/g;
					$id_value =~ s/$/\"/g;
					
					$d_ref->{$id_name} = $id_value;
				}
			}
			
			$d_ref->{Object_Name} =~ s/\.//g;
			
			$d_ref->{Object_Name} =~ s/\:/_/g;
			
			$d_ref->{Object_Name} =~ tr/\=\,/_\//;
		}

		return 0;
	 },
  }, ## end Processing Multi-lined Object Names
    
  
  
     { ## Processing Single-lined Object Names for V33
         RULE_TYPE => 'Generic_ASCII',
         RULE_DESC => 'HUAWEI NSS V33 DATA',
         INPUT_FILE_DESCRIPTION => [ 
				'^\w+_AINTSPEM_\w+_\d{8}\.TXT$',
				'^\w+_ASSPROM_\w+_\d{8}\.TXT$',
				'^\w+_AUTHSM_\w+_\d{8}\.TXT$',
				'^\w+_BSCRM_\w+_\d{8}\.TXT$',
				'^\w+_C7LL_\w+_\d{8}\.TXT$',
				'^\w+_CANSW_\w+_\d{8}\.TXT$',
				'^\w+_CHECKIMEIPM_\w+_\d{8}\.TXT$',
				'^\w+_CPROM_\w+_\d{8}\.TXT$',
				'^\w+_CPXX_\w+_\d{8}\.TXT$',
				'^\w+_DESTDMBOD_\w+_\d{8}\.TXT$',
				'^\w+_DEST_\w+_\d{8}\.TXT$',
				'^\w+_DROP_\w+_\d{8}\.TXT$',
				'^\w+_DTRM_\w+_\d{8}\.TXT$',
				'^\w+_FAIL_\w+_\d{8}\.TXT$',
				'^\w+_FTOICTM_\w+_\d{8}\.TXT$',
				'^\w+_HOV_\w+_\d{8}\.TXT$',
				'^\w+_ICSUBTOOPCTM_\w+_\d{8}\.TXT$',
				'^\w+_INCM_\w+_\d{8}\.TXT$',
				'^\w+_INCTRDDM_\w+_\d{8}\.TXT$',
				'^\w+_INEM_\w+_\d{8}\.TXT$',
				'^\w+_INSMOM_\w+_\d{8}\.TXT$',
				'^\w+_INSM_\w+_\d{8}\.TXT$',
				'^\w+_ITOFCTM_\w+_\d{8}\.TXT$',
				'^\w+_ITOICTM_\w+_\d{8}\.TXT$',
				'^\w+_ITOMCTM_\w+_\d{8}\.TXT$',
				'^\w+_IWF10CHM_\w+_\d{8}\.TXT$',
				'^\w+_LSETM_\w+_\d{8}\.TXT$',
				'^\w+_LUPAG_\w+_\d{8}\.TXT$',
				'^\w+_MAPCSPEM_\w+_\d{8}\.TXT$',
				'^\w+_MAPINSM_\w+_\d{8}\.TXT$',
				'^\w+_MAPSPETM_\w+_\d{8}\.TXT$',
				'^\w+_MSCBTM_\w+_\d{8}\.TXT$',
				'^\w+_MSC_\w+_\d{8}\.TXT$',
				'^\w+_MTCCM_\w+_\d{8}\.TXT$',
				'^\w+_MTOICTM_\w+_\d{8}\.TXT$',
				'^\w+_OBSCHM_\w+_\d{8}\.TXT$',
				'^\w+_ORGTRDDM_\w+_\d{8}\.TXT$',
				'^\w+_SCCPAM_\w+_\d{8}\.TXT$',
				'^\w+_SCCPPM_\w+_\d{8}\.TXT$',
				'^\w+_SCCPURM_\w+_\d{8}\.TXT$',
				'^\w+_SCIPHERMSPM_\w+_\d{8}\.TXT$',
				'^\w+_SMSFAX_\d{8}\.TXT',
				'^\w+_TCAPAM_\w+_\d{8}\.TXT$',
				'^\w+_TCAPCURM_\w+_\d{8}\.TXT$',
				'^\w+_TCAPMAM_\w+_\d{8}\.TXT$',
				'^\w+_TCAPSLPPM_\w+_\d{8}\.TXT$',
				'^\w+_TCAPTSLPM_\w+_\d{8}\.TXT$',
				'^\w+_TCAPCSLPM_\w+_\d{8}\.TXT$',
				'^\w+_TGRP2_\w+_\d{8}\.TXT$',
				'^\w+_TGRP3_\w+_\d{8}\.TXT$',
				'^\w+_TGRP_\w+_\d{8}\.TXT$',
				'^\w+_TMSIRSPM_\w+_\d{8}\.TXT$',
				'^\w+_TRMBCT_\w+_\d{8}\.TXT$',
				'^\w+_VLRTM_\w+_\d{8}\.TXT$',
				'^\w+_FAIL_\w+_\d{8}\.TXT$',
				'^\w+_DSPM_\w+_\d{8}\.TXT$',
				],
         INPUT_DIR_DEPTH => 0,
         ORDER_OF_FILES => 'OLDEST_FIRST',

	 OUTPUT_BLOCK_NAME          => 'HUAWEI_NSS',
	 DEFAULT_NULL_VALUE         => '',
	 UPPERCASE_COUNTERS         => 0,
	 FILENAME_HEADER_FIELDS      => {
		FILENAME	=> '(.*)',
		ORIGINAL_FILENAME	=> '(.*)',
		MSC_NAME	=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
		NODEID		=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
		MSC_ID		=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
		BLOCKNAME	=> '^[A-Za-z0-9]+_(\w+)_\d{8}\.TXT$',
	 },

	 HEADER_INFO_TO_KEY_PIF_FILENAME => ['FILENAME'],

 
         HEADER_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\=+
*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				%$d_href = ();
				delete $rule_obj->{COUNTER_NAMES};
				if ($rule_obj->{OLD_FILENAME} ne $h_href->{ORIGINAL_FILENAME}) {
					$rule_obj->{OLD_FILENAME} = $h_href->{ORIGINAL_FILENAME};
					$rule_obj->{BLOCK_COUNTER} = 0;
				}
				$rule_obj->{BLOCK_COUNTER}++;	
				$h_href->{FILENAME} = $h_href->{ORIGINAL_FILENAME} . "_PART_" . $rule_obj->{BLOCK_COUNTER};
				return 'NEXTLINE';
			},
		},
		
		{
			LINE_DESCRIPTION => '^\d{4}-\d{2}-\d{2}\ \d{2}:\d{2}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				@{$rule_obj->{COUNTER_NAMES}}[0] = 'Object_Name';
				return 'GODATA';
			},
		},
		
		{
			LINE_DESCRIPTION => '^(.*\|){2,}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;

			    my $line = $$line_sref;
			    
			    chomp $line;				
				
				# Substitute double quotes with null
				$line =~ s/\"//g;
				
				$line =~ s/
//g;
				
				if (exists ($rule_obj->{COUNTER_NAMES})) {
					
					my @temp_array_1 = split /\|/, $line;
					my @temp_array_2 = @{$rule_obj->{COUNTER_NAMES}};
					my @new_countername;
					
					my $array1Index;
					my $numElements = scalar(@temp_array_1);
					
					
					for($array1Index=0; $array1Index < $numElements; $array1Index++) {
				        $temp_array_1[$array1Index] =~ s/
//g;
				 		$temp_array_1[$array1Index] =~ s/ $//;
					}
					
					foreach my $item (@temp_array_2) {
						my $temp_name = shift @{$rule_obj->{COUNTER_NAMES}} ;
						$temp_name .= shift @temp_array_1;
						push @new_countername, $temp_name;
					}
					
					my $counterNameIndex;
					for($counterNameIndex=0; $counterNameIndex<scalar(@new_countername); $counterNameIndex++) {

						$new_countername[$counterNameIndex] =~ s/ /_/g;
					}

					$rule_obj->{COUNTER_NAMES} = \@new_countername;
				}
				else {
					my @temp = split /\|/, $line;
					$rule_obj->{COUNTER_NAMES} = \@temp;
					
					my $array1Index;
					my $numElements = scalar(@temp);
					
					for($array1Index=0; $array1Index < $numElements; $array1Index++) {
						$temp[$array1Index] =~ s/ $//;
					}
					
					
				}
				return 'NEXTLINE';
			},
		},
					],
	 DATA_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\=+
*$',
			LINE_PROCESSING  => sub {
				return 'GOHEADER';
			},
		},
		
	 	{
			LINE_DESCRIPTION => '^\d{4}-\d{2}-\d{2}\ \d{2}:\d{2}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;

				($d_href->{START_DATE}, $d_href->{START_TIME}, my $discard,$d_href->{GP}) = split /\ /, $line; 
				$d_href->{GP} *= 60;
				
				return 'NEXTLINE';
			},
		},
		
	 	{
			
			LINE_DESCRIPTION => '^(.*\|){2,}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;
				$line =~ s/\ +\|/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ tr/\n\t -~//cd;
				$line =~ s/\ *
*$//g;
				$line =~ s/\ *\=\ */\=/g;
				$line =~ s/\ *\,\ */\,/g;
				$line =~ s/(\d+)\,(\d+)/$1\.$2/g;
				$line =~ s/(\d+)\%/$1/g;
				$line =~ s/\ /_/g;
				
				
				$line =~ s/\-/_/g;
				
				$line =~ s/\_\_+//g;
				
				
				$line =~ s/\<NULL\>//g;
				$line =~ s/\*//g;
				$line =~ s/_{2,}/_/g;
				$line =~ s/_$//g;
				
								
				my @counter_value = split /\|/, $line;
				foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
					$d_href->{$counter_name} = shift @counter_value;
				}
				return 'WRITEPIF';
			},
		},
	],
	 HEADER_DATA_RECORD_PROCESSING => sub {
		my ($blk_name_ref, $h_ref, $d_ref) = @_;

		# Set block name
		#$h_ref->{BLOCKNAME} =~ s/\_REPORT(_\d+)*//g;
		$h_ref->{BLOCKNAME} =~ s/\_REPORT//g;
		$$blk_name_ref = $h_ref->{BLOCKNAME};
		
		# Format the counters to remove extra underscores
		foreach my $cname_ori (keys %$d_ref) {
			my $cname_new = $cname_ori;
			
			
			$cname_new =~ s/\-/_/g;
			
			
			$cname_new =~ s/_{2,}/_/g;
			
			
			
			$cname_new =~ s/\_+$//g;
			$cname_new =~ s/\_+/\_/g;
			$cname_new =~ s/\(//g;
			$cname_new =~ s/\)//g;
			
			## remove forward slash
			$cname_new =~ s/\//\_/g;
			## remove commas
			$cname_new =~ s/\,//g;
			##remove ampersand
			$cname_new =~ s/\&//g;
			##replace space with NULL
			$cname_new =~ s/\s+//g;
			
			
			
			$d_ref->{$cname_new} = $d_ref->{$cname_ori};
			delete $d_ref->{$cname_ori} if $cname_new ne $cname_ori;
		}

		# Split up Objects
		if (exists($d_ref->{Object_Name})){
			
			my @object_name = split /\,/, $d_ref->{Object_Name};
			my $id_name;
			my $id_value;
			
			foreach my $oname_ori (@object_name) {
				if ($oname_ori =~ /(.*)\:(.*)/) {
				#if($oname_ori =~ /(\w+?\s*\w*\.{0,})\:(.*)/ ){
					if($oname_ori =~ /^LAI_No\.\:([a-zA-z0-9]{5})(.*)/ ){
						$d_ref->{MMC_MNC} = $1;
						$d_ref->{LAC_No} = 	hex($2);
						$d_ref->{LAI_No} = $1.$2;
					}
					else{
						$id_name = $1;
						$id_value = $2;
						$id_name =~ s/\.//g;
						$d_ref->{$id_name} = $id_value;
					}
				}
			}
			$d_ref->{Object_Name} =~ s/\.//g;
			$d_ref->{Object_Name} =~ s/\:/_/g;
			$d_ref->{Object_Name} =~ tr/\=\,/_\//;
			
			if ($$blk_name_ref eq 'TRMBCT'){
				$d_ref->{'Connection_Type'} = $d_ref->{Object_Name};
				delete $d_ref->{Object_Name};
			}
		}

		return 0;
	 },
 }, ## end Processing Single-lined Object Names for V33. 
 
 
 
     {  ##Processing Single-lined Object Names for V33 (LUPAG, PAGING).
         RULE_TYPE => 'Generic_ASCII',
         RULE_DESC => 'HUAWEI NSS V33 DATA - LUPAG, PAGING',
         INPUT_FILE_DESCRIPTION => [ 
				'^\w+_LUPAG\,PAGING\_\w+_\d{8}.TXT$',
				],
         INPUT_DIR_DEPTH => 0,
         ORDER_OF_FILES => 'OLDEST_FIRST',

	 	OUTPUT_BLOCK_NAME          => 'HUAWEI_NSS',
	 	DEFAULT_NULL_VALUE         => '',
	 	UPPERCASE_COUNTERS         => 0,
	 	FILENAME_HEADER_FIELDS      => {
		FILENAME	=> '(.*)',
		ORIGINAL_FILENAME	=> '(.*)',
		MSC_NAME	=> '^([A-Za-z0-9]+)_\w+,\w+_\d{8}\.TXT$',
		NODEID		=> '^([A-Za-z0-9]+)_\w+,\w+_\d{8}\.TXT$',
		MSC_ID		=> '^([A-Za-z0-9]+)_\w+,\w+_\d{8}\.TXT$',
		BLOCKNAME	=> '^[A-Za-z0-9]+_(\w+),\w+_\w+_\d{8}\.TXT$',
	 },

	 HEADER_INFO_TO_KEY_PIF_FILENAME => ['FILENAME'],

         
        HEADER_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\=+
*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				%$d_href = ();
				delete $rule_obj->{COUNTER_NAMES};
				if ($rule_obj->{OLD_FILENAME} ne $h_href->{ORIGINAL_FILENAME}) {
					$rule_obj->{OLD_FILENAME} = $h_href->{ORIGINAL_FILENAME};
					$rule_obj->{BLOCK_COUNTER} = 0;
				}
				$rule_obj->{BLOCK_COUNTER}++;	
				$h_href->{FILENAME} = $h_href->{ORIGINAL_FILENAME} . "_PART_" . $rule_obj->{BLOCK_COUNTER};
				return 'NEXTLINE';
			},
		},
		{
			LINE_DESCRIPTION => '^\d{4}-\d{2}-\d{2}\ \d{2}:\d{2}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				@{$rule_obj->{COUNTER_NAMES}}[0] = 'Object_Name';
				return 'GODATA';
			},
		},
		{
			LINE_DESCRIPTION => '^(.*\|){2,}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;

			        my $line = $$line_sref;
				$line =~ s/\ *
//g;
				#$line =~ s/\s{1,}\ *^M/_/g;
				$line =~ s/\ \|/\|/g;
				$line =~ s/\ /_/g;
				$line =~ s/_+\|/\_\|/g;
				$line =~ s/\-/_/g;
				$line =~ s/,/_/g;
				$line =~ s/\//_/g;
				$line =~ s/\&//g;
				$line =~ s/_{2,}/_/g;
				$line =~ s/_$//g;

				if (exists ($rule_obj->{COUNTER_NAMES})) {
					my @temp_array_1 = split /\|/, $line;
					my @temp_array_2 = @{$rule_obj->{COUNTER_NAMES}};
					my @new_countername;
					foreach my $item (@temp_array_2) {
						my $temp_name = shift @{$rule_obj->{COUNTER_NAMES}} ;
						$temp_name .= shift @temp_array_1;
						push @new_countername, $temp_name;
					}
					$rule_obj->{COUNTER_NAMES} = \@new_countername;
				}
				else {
					my @temp = split /\|/, $line;
					$rule_obj->{COUNTER_NAMES} = \@temp;
					
					
				}
				return 'NEXTLINE';
			},
		},
					],
	 DATA_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\=+
*$',
			LINE_PROCESSING  => sub {
				return 'GOHEADER';
			},
		},
	 	{
			LINE_DESCRIPTION => '^\d{4}-\d{2}-\d{2}\ \d{2}:\d{2}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;

				($d_href->{START_DATE}, $d_href->{START_TIME}, my $discard,$d_href->{GP}) = split /\ /, $line; 
				$d_href->{GP} *= 60;
				
				return 'NEXTLINE';
			},
		},
		
	 	{
			LINE_DESCRIPTION => '^(.*\|){2,}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			    my $line = $$line_sref;
				$line =~ s/\ +\|/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ tr/\n\t -~//cd;
				$line =~ s/\ *
*$//g;
				$line =~ s/\ *\=\ */\=/g;
				$line =~ s/\ *\,\ */\,/g;
				$line =~ s/(\d+)\,(\d+)/$1\.$2/g;
				$line =~ s/(\d+)\%/$1/g;
				$line =~ s/\ /_/g;
				$line =~ s/\_\_+//g;
				$line =~ s/\<NULL\>//g;
				$line =~ s/\*//g;
				my @counter_value = split /\|/, $line;
				foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
					$d_href->{$counter_name} = shift @counter_value;
				}
				return 'WRITEPIF';
			},
		},
	],
	 HEADER_DATA_RECORD_PROCESSING => sub {
		my ($blk_name_ref, $h_ref, $d_ref) = @_;


		# Set block name
		$h_ref->{BLOCKNAME} =~ s/\_REPORT//g;
		$$blk_name_ref = $h_ref->{BLOCKNAME};

		# Format the counters to remove extra underscores
		foreach my $cname_ori (keys %$d_ref) {
			my $cname_new = $cname_ori;
			$cname_new =~ s/\_+$//g;
			$cname_new =~ s/\_+/\_/g;
			$cname_new =~ s/\(//g;
			$cname_new =~ s/\)//g;
			$d_ref->{$cname_new} = $d_ref->{$cname_ori};
			delete $d_ref->{$cname_ori} if $cname_new ne $cname_ori;
		}

		# Split up Objects
		if (exists($d_ref->{Object_Name})){
			my $id_name;
			my $id_value; 
			my @object_name = split /\,/, $d_ref->{Object_Name};
			foreach my $oname_ori (@object_name) {
				if ($oname_ori =~ /(.*)\:(.*)/) {
				#if($oname_ori =~ /(\w+?\s*\w*\.{0,})\:(.*)/ ){	
					if($oname_ori =~ /^LAI_No\.\:([a-zA-z0-9]{5})(.*)/ ){
						$d_ref->{MMC_MNC} = $1;
						$d_ref->{LAC_No} = 	hex($2);
						$d_ref->{LAI_No} = $1.$2;
					}
					else{
						$id_name = $1;
						$id_value = $2;
						$id_name =~ s/\.//g;
						$d_ref->{$id_name} = $id_value;
					}
				}
			}
			$d_ref->{Object_Name} =~ s/\.//g;
			$d_ref->{Object_Name} =~ s/\:/_/g;
			$d_ref->{Object_Name} =~ tr/\=\,/_\//;

		}

		return 0;
	 },
 },  ## end Processing Single-lined Object Names for V33 ("LUPAG,PAGING" type)
 
 
 
     { ## Processing V61 Single-lined Object Names
         RULE_TYPE => 'Generic_ASCII',
         RULE_DESC => 'HUAWEI NSS V61 HIERARCHY',
         INPUT_FILE_DESCRIPTION => [ 
				'^\w+\.DISP\w*\.TXT$' ,
				],
         INPUT_DIR_DEPTH => 0,
         ORDER_OF_FILES => 'OLDEST_FIRST',

	 OUTPUT_BLOCK_NAME          => 'DISP',
	 DEFAULT_NULL_VALUE         => '',
	 UPPERCASE_COUNTERS         => 0,
	 FILENAME_HEADER_FIELDS      => {
		FILENAME	=> '(.*)',
		MSC_NAME	=> '^([A-Za-z0-9]+)\.DISP\w*\.TXT$',
		MSC_ID		=> '^([A-Za-z0-9]+)\.DISP\w*\.TXT$',
		NODEID		=> '^([A-Za-z0-9]+)\.DISP\w*\.TXT$',
		OLD_BLOCKNAME	=> '^[A-Za-z0-9]+\.(DISP\w*)\.TXT$',
	 },

	 HEADER_INFO_TO_KEY_PIF_FILENAME => ['FILENAME'],

         HEADER_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^(\-+\s*)+
*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				%$d_href = ();
				$rule_obj->{BLOCK_COUNTER}++;	
				$h_href->{BLOCKNAME} = $h_href->{OLD_BLOCKNAME} . "_" . $rule_obj->{BLOCK_COUNTER};
				return 'GODATA';
			},
		},
	 	{
			# FILE HEADER
			LINE_DESCRIPTION => '^Office\ number.*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;
				$line =~ s/\t/\|/g;
				$line =~ s/\ +\|/\|/g;
				$line =~ s/\|\ +/\|/g;
				#$line =~ s/\ \ +/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ s/\.//g;
				$line =~ s/\-/_/g;
				$line =~ s/\ /_/g;
				$line =~ s/_$//g;
				my @dref_keys = split /\|/, $line;
				$rule_obj->{COUNTER_NAMES} = \@dref_keys;
				return 'NEXTLINE';
			},
		},
	 	{
			# FILE HEADER
			LINE_DESCRIPTION => '^Module\ ID.*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			    my $line = $$line_sref;
				$line =~ s/\t/\|/g;
				$line =~ s/\ +\|/\|/g;
				$line =~ s/\|\ +/\|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ s/\.//g;
				$line =~ s/\-/_/g;
				$line =~ s/\ /_/g;
				$line =~ s/_$//g;
				my @dref_keys = split /\|/, $line;
				$rule_obj->{COUNTER_NAMES} = \@dref_keys;
				return 'NEXTLINE';
			},
		},
	 ],
	 
	 DATA_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^(\-+\s*)+
*$',
			LINE_PROCESSING  => sub {
				return 'NEXTLINE';
			},
		},
	 	{
			LINE_DESCRIPTION => '^
*$',
			LINE_PROCESSING  => sub {
				return 'NEXTLINE';
			},
		},
	 	{
			LINE_DESCRIPTION => '^.*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			    my $line = $$line_sref;
				$line =~ s/\s\s*/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ s/\ /_/g;
				$line =~ s/^\|//g;
				if ($line =~ /^\w+\|\w+\|\w+/) {
					my @counter_value = split /\|/, $line;
					foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
						$d_href->{$counter_name} = shift @counter_value;
					}
					return 'WRITEPIF';
				}
				else {
					return 'NEXTLINE';
				}
			},
		},
	 ],
	 #HEADER_DATA_RECORD_PROCESSING => 


 	}, ## end Processing Single-lined Object Names ...
);  


sub engine_config {
    return \@rules;
}

1;
