#
#-------------------------------------------------------------------------------
# @(#) huawei-nss/V33/UserConfig.pm huawei-nss_r3.3.0.latest:cset.003248:4:4@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Copyright (c) 2007 IBM Tivoli Software Systems. All rights reserved.
#

package UserConfig;

@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use Exporter ();

#-------------------------------------------------------------------------------

my @rules = (
#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------

{
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert DISP information into files',
        INPUT_FILE_DESCRIPTION  => [
                '^(\w+)_C7LL_REPORT_\d{8}\.TXT_PART_\d+-#-C7LL-#-I\.pif$',
        ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD     =>      [],
        NAMES_USED_TO_ID_DATA_RECORD    => ['Module_No', 'Link_No'],
        INFO_FILE_DESCRIPTION   => ['^(\w+)\.DISP\.TXT-#-DISP-#-I\.pif'],
        HEADER_NAMES_USED_TO_ID_INFORMATION     => [],
        NAMES_USED_TO_ID_INFORMATION    => ['Module_ID', 'Link_identifier'],
        OUTPUT_FILENAME_START   => 'II',
        WRITE_DATA_LINE => 'True',
        REDUNDANT_DATA_COUNTERS         => [],
        PRODUCE_LIF     => 'True',
        PRODUCE_PIF     => 0,

},

{
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert DISPTG information into files',
        INPUT_FILE_DESCRIPTION  => [
                '^(\w+)_TGRP_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP-#-I\.pif$',
        ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD     =>      [],
        NAMES_USED_TO_ID_DATA_RECORD    => ['Office_dire_No'],
        INFO_FILE_DESCRIPTION   => ['^(\w+)\.DISPTG\.TXT-#-DISP-#-I\.pif'],
        HEADER_NAMES_USED_TO_ID_INFORMATION     => [],
        NAMES_USED_TO_ID_INFORMATION    => ['Office_number'],
        OUTPUT_FILENAME_START   => 'II',
        WRITE_DATA_LINE => 'True',
        REDUNDANT_DATA_COUNTERS         => [],
        PRODUCE_PIF     => 0,
        PRODUCE_LIF     => 'True',

},

{
        RULE_TYPE               => 'JOIN',
        RULE_DESC               => 'JOINING THE TGRP, TGRP2, TGRP3 FILES',
        INPUT_FILE_DESCRIPTION  => [
                '\w+_TGRP\d*_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP\d*-#-I\.pif$',
        ],
       	OUTPUT_BLOCK_NAME 		=> 'TGRP',
       	REDUNDANT_DATA_COUNTERS	=> [],
       	#COUNTERS_TO_JOIN_ON		=> ['MSC_ID'],
       	COUNTERS_TO_JOIN_ON		=> ['MSC_ID', 'Office_dire_No', 'START_TIME'],
       	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME	=> ['MSC_ID', 'BLOCKNAME'],
       	OUTPUT_FILENAME_START	=>	'TGRP_MSC_JOIN',
       	HOURS_TO_WAIT_FOR_PARTNER_FILES	=> -1,
       	QUOTE_INPUT_PIFS	=> 'True',
       	REDUNDANT_HEADER_COUNTERS	=> [],
        PRODUCE_LIF     => 'True',
        PRODUCE_PIF     => 'True',
},


{
		'RULE_TYPE'	=> 'AGGREGATE_LINE',
		'RULE_DESC'	=> 'SUM UP COUNTERS BASED ON MSC TRAFFIC TYPE',
		'INPUT_FILE_DESCRIPTION' 	=>	'\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-\#-MSC-\#-I.pif',
		'REDUNDANT_DATA_COUNTERS'	=>	[],
		'DEFAULT_NULL_VALUE'		=>	'NULL',
		'COUNTER_GROUPS'				=>	{
			'Wrong_dialing_number_times'	=>	'Wrong_dialing_number_times_\w+',
			'Internal_congestion_times'		=> 	'Internal_congestion_times_\w+',
			'Seized_traffic'				=>	'Seized_traffic_\w+',
			'Abandoned_calls_before_ring'	=>	'Abandoned_calls_before_ring_\w+',
			'Lack_common_resource_times'	=>	'Lack_common_resource_times_\w+',
			'Internal_congestion_times'		=>	'Internal_congestion_times_\w+',
			'Answered_calls'				=>	'Answered_calls_\w+',	
			'TK_bid_times'					=>	'TK_bid_times_\w+',
			'Attempted_calls'				=>	'Attempted_calls_\w+',
			'Answered_traffic'				=>	'Answered_traffic_\w+',
			'Abandoned_calls_after_ring'						=>	'Abandoned_calls_after_ring_\w+',	
			'No_paging_response_times'							=>	'No_paging_response_times_\w+',
			'Assign_failure_times_for_MT'						=>	'Assign_failure_times_for_MT_\w+',
			'Subscribers_of_own'								=>	'Subscribers_of_own_\w+',
			'Connected_calls'									=>	'Connected_calls_\w+',
			'Assign_failure_times_for_MT'						=>	'Assign_failure_times_for_MT_\w+',
			'Assign_failure_times_for_MO'						=>	'Assign_failure_times_for_MO_\w+',
			'Overflow_times_on_the_A_circuits_to_BSS_MT_located'	=>	'Overflow_times_on_the_A_circuits_to_BSS_MT_located_\w+',
			'Internal_congestion_times'							=>	'Internal_congestion_times_\w+',
			'Overflow_calls_on_the_last_choice_route'			=>	'Overflow_calls_on_the_last_choice_route_\w+',
			'Calls_canceled_by_MT'								=>	'Calls_canceled_by_MT_\w+',
			'Calls_ringed_no_answer'							=>	'Calls_ringed_no_answer_\w+',
			'Called_party_busy_times'							=>	'Called_party_busy_times_\w+',
			'Set_cipher_mode_failure_times_on_MO'				=>	'Set_cipher_mode_failure_times_on_MO_\w+',	
			'External_congestion_times'							=>	'External_congestion_times_\w+',
			'Overflow_times_on_A_circuits_to_BSS_MO_located'	=>	'Overflow_times_on_A_circuits_to_BSS_MO_located_\w+',						
			'Overflow_calls_on_the_last_choice_route'			=>	'Overflow_calls_on_the_last_choice_route_\w+',
		},
		'OUTPUT_BLOCK_NAME'		=>	'MSC_AGGR',		
		'PRODUCE_PIF'			=>	'True',
		'PRODUCE_LIF'			=>	0,  
},	


{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'REMOVING THE TRAFFIC TYPE SUFFIX FOR THE AGGREGATED_LINE COUNTERS ...',
        INPUT_FILE_DESCRIPTION  => [
                                        '\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-\#-MSC-\#-I-#-AL.pif',
                                ],
                                
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;
				
                foreach my $cname (grep {/^(.*)_(ORG|INT|ORGOEX|IEX|IEXTE|TE|TRA|OEX)$/} keys %{$d_ref}) {
                        $d_ref->{$cname} = '';
                }
                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_AGGR',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},


## commented - not needed for this release (Oct 23 '07). Was needed in the earlier release back in Jan '07.
#{
#        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
#        RULE_DESC => 'Split up MSC_REPORT files based on traffic type',
#        INPUT_FILE_DESCRIPTION => [
#				   '^\w+_TGRP\d_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP\d-#-I\.pif$',
#				   '^\w+_TGRP\d*_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP\d*-#-I\.pif$',
#				   '^\w+_TGRP_REPORT_\d{8}\.TXT_PART_\d+-\#-TGRP-\#-I\.pif$',
#				  ],
#        SPLIT_CNAMES => {
#               TGRP_BI     => [ '^Bidirectional_\w+$' ,
#				 '^\w+_bidirectional_\w+$'
#				],
#               TGRP_IN     => [ '^Unilateralism_incoming_\w+$' ,
#				 '^\w+_unilateralism_incoming_\w+$'
#				],
#                TGRP_OUT     => [ '^Unilateralism_outgoing_\w+$' ,
#				 '^\w+_unilateralism_outgoing_\w+$',
#				 '^Unilateralism_against_office_no_rsp_times$'
#				],
#        },
#        ONLY_INSERT     => ['ORIGINAL_FILENAME', 'NODEID', 'MSC_ID','Credibility','GP','START_TIME','START_DATE','Office_dire_No','Object_Name'],
#        PRODUCE_PIF => 'True',
#        OUTPUT_BLOCK_NAME => 'TGRP_SPLIT',
#        OUTPUT_FORMAT => 0,
#},


{
        RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
        RULE_DESC => 'Split up MSC_REPORT files based on traffic type',
        INPUT_FILE_DESCRIPTION => ['^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I\.pif$'],
        SPLIT_CNAMES => {
                ORG     => [ '^\w+_ORG$' ],
                INT     => [ '^\w+_INT$' ],
                ORGOEX  => [ '^\w+_ORGOEX$' ],
                IEX     => [ '^\w+_IEX$' ],
                IEXTE   => [ '^\w+_IEXTE$' ],
                TE      => [ '^\w+_TE$' ],
                TRA     => [ '^\w+_TRA$' ],
                OEX     => [ '^\w+_OEX$' ],
                        },
        ONLY_INSERT     => ['ORIGINAL_FILENAME', 'NODEID', 'MSC_ID','Credibility','GP','START_TIME','START_DATE','Object_Name'],
        PRODUCE_PIF => 'True',
        OUTPUT_BLOCK_NAME => 'TRAFTYPE',
        OUTPUT_FORMAT => 0,
},


{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE OEX',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-OEX-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_OEX$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_OEX$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'OEX';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},

{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE TRA',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-TRA-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_TRA$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_TRA$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'TRA';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},

{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE TE',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-TE-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_TE$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_TE$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'TE';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},

{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE IEXTE',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-IEXTE-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_IEXTE$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_IEXTE$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'IEXTE';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE IEX',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-IEX-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_IEX$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_IEX$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'IEX';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE ORGOEX',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-ORGOEX-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_ORGOEX$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_ORGOEX$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'ORGOEX';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE INT',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-INT-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_INT$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_INT$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'INT';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE ORG',
        INPUT_FILE_DESCRIPTION  => [
                                        '^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-ORG-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/_ORG$/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/_ORG$//;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }
                $d_ref->{'Traffic_type'} = 'ORG';

                return 0;
        },
        OUTPUT_BLOCK_NAME       => 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregrate CELLTD files to MSC level',
        INPUT_FILE_DESCRIPTION => [
                                        '^\w+_CELLTD_REPORT_\d{8}\.TXT_PART_\d+-#-CELLTD-#-I\.pif$',
                                        ],
        COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
        OUTPUT_BLOCK_NAME       => 'CELLTD_AGGR',
        PRODUCE_PIF             => 0,
        OUTPUT_FORMAT           => 'LIF_Writer',
        NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME)],
        REDUNDANT_DATA_COUNTERS         => [],
},
{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregrate LUPAG files to MSC level',
        INPUT_FILE_DESCRIPTION => [
                                        '^\w+_LUPAG_REPORT_\d{8}\.TXT_PART_\d+-#-LUPAG-#-I\.pif$',
                                        ],
        COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
        OUTPUT_BLOCK_NAME       => 'LUPAG_AGGR',
        PRODUCE_PIF             => 0,
        OUTPUT_FORMAT           => 'LIF_Writer',
        NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME BSC_DPC MMC_MNC LAC_No)],
        REDUNDANT_DATA_COUNTERS         => [],
},
{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregrate OBSCHM files to MSC level',
        INPUT_FILE_DESCRIPTION => [
                                        '^\w+_OBSCHM_REPORT_\d{8}\.TXT_PART_\d+-#-OBSCHM-#-I\.pif$',
                                        ],
        COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
        OUTPUT_BLOCK_NAME       => 'OBSCHM_AGGR',
        PRODUCE_PIF             => 0,
        OUTPUT_FORMAT           => 'LIF_Writer',
        NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME)],
        REDUNDANT_DATA_COUNTERS         => [],
},
{
        RULE_TYPE               => 'ACCUMULATE',
        RULE_DESC               => 'Aggregrate ASSPROM files to MSC level',
        INPUT_FILE_DESCRIPTION => [
                                        '^\w+_ASSPROM_REPORT_\d{8}\.TXT_PART_\d+-#-ASSPROM-#-I\.pif$',
                                        ],
        COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
        OUTPUT_BLOCK_NAME       => 'ASSPROM_AGGR',
        PRODUCE_PIF             => 'TRUE',
        OUTPUT_FORMAT           => 0,
        NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME BSC_DPC)],
        REDUNDANT_DATA_COUNTERS         => [],
},
{
	'RULE_TYPE'              => 'PIF_REMOVE',
	'RULE_DESC'              => 'REMOVE unneeded files',
	'INPUT_FILE_DESCRIPTION' => [
                			'^\w+_TGRP_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP-#-I\.pif$',
        				'^\w+_TGRP\d_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP\d-#-I\.pif$',
                			'^\w+_C7LL_REPORT_\d{8}\.TXT_PART_\d+-#-C7LL-#-I\.pif$',
					],
	'PRODUCE_PIF'            => 'True',
	'PRODUCE_LIF'            => 0,
},

## commented the TGRP parts - all TGRP_* types are joined into a single file as in TGRP_MSC_JOIN file
#{
#	'RULE_TYPE'              => 'PIF_2_OUTPUT',
#	'RULE_DESC'              => 'OUTPUT TGRP INCOMING FILES',
#	'INPUT_FILE_DESCRIPTION' => [
#				     '^\w+_TGRP\d_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP\d-#-I-#-TGRP_IN-#-FSC\.pif$',
#				     '^\w+_TGRP_REPORT_\d{8}\.TXT_PART_\d+-\#-TGRP-\#-I-\#-TGRP_IN-\#-FSC\.pif$'
#				    ],
#	'OUTPUT_BLOCK_NAME'	 => 'TGRP_IN',
#	'PRODUCE_PIF'            => 0,
#	'PRODUCE_LIF'            => 'True',
#},
#{
#	'RULE_TYPE'              => 'PIF_2_OUTPUT',
#	'RULE_DESC'              => 'OUTPUT TGRP OUTGOING FILES',
#	'INPUT_FILE_DESCRIPTION' => [
#				     '^\w+_TGRP\d_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP\d-#-I-#-TGRP_OUT-#-FSC\.pif$',
#				     '^\w+_TGRP_REPORT_\d{8}\.TXT_PART_\d+-\#-TGRP-\#-I-\#-TGRP_OUT-\#-FSC\.pif$'
#				    ],
#	'OUTPUT_BLOCK_NAME'	 => 'TGRP_OUT',
#	'PRODUCE_PIF'            => 0,
#	'PRODUCE_LIF'            => 'True',
#},
#{
#	'RULE_TYPE'              => 'PIF_2_OUTPUT',
#	'RULE_DESC'              => 'OUTPUT TGRP BIDIRECTIONAL FILES',
#	'INPUT_FILE_DESCRIPTION' => [
#				     '^\w+_TGRP\d_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP\d-#-I-#-TGRP_BI-#-FSC\.pif$',
#				     '^\w+_TGRP_REPORT_\d{8}\.TXT_PART_\d+-\#-TGRP-\#-I-\#-TGRP_BI-\#-FSC\.pif$'
#				    ],
#	'OUTPUT_BLOCK_NAME'	 => 'TGRP_BI',
#	'PRODUCE_PIF'            => 0,
#	'PRODUCE_LIF'            => 'True',
#},
### commented until this closing brace...

{
	'RULE_TYPE'              => 'PIF_2_OUTPUT',
	'RULE_DESC'              => 'OUTPUT COMBCDOTM1 FILES',
	'INPUT_FILE_DESCRIPTION' => [
					#'^\w+_COMBCDOTM1_REPORT_\d{8}\.TXT-\#-COMBCDOTM1-\#-I\.pif$',
					#'^\w+_COMBCDOTM2_REPORT_\d{8}\.TXT-\#-COMBCDOTM2-\#-I\.pif$',
					'^\w+_COMBCDOTM1_REPORT_\d{8}\.TXT_PART_\d+-\#-COMBCDOTM1-\#-I\.pif$',
					#'^\w+_COMBCDOTM2_REPORT_\d{8}\.TXT_PART_\d+-\#-COMBCDOTM2-\#-I\.pif$',
				    ],
	'PRODUCE_PIF'            => 0,
	'PRODUCE_LIF'            => 'True',
    'OUTPUT_BLOCK_NAME' 	 => 'COMBCDOTM1',

},


{
	'RULE_TYPE'              => 'PIF_2_OUTPUT',
	'RULE_DESC'              => 'OUTPUT COMBCDOTM2 FILES',
	'INPUT_FILE_DESCRIPTION' => [
					
					'^\w+_COMBCDOTM2_REPORT_\d{8}\.TXT_PART_\d+-\#-COMBCDOTM2-\#-I\.pif$',
				    ],
	'PRODUCE_PIF'            => 0,
	'PRODUCE_LIF'            => 'True',
    'OUTPUT_BLOCK_NAME' 	 => 'COMBCDOTM2',

},


## is : aug 2007
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct TMSIRSPM',
        INPUT_FILE_DESCRIPTION  => [
                                        '\w+_TMSIRSPM_REPORT_\d{8}\.TXT_PART_\d+-\#-TMSIRSPM-\#-I.pif',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/realloctimes/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/realloctimes/realloc_times/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-TMSIRSPM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},

{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct SCIPHERMSPM_REPORT',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_SCIPHERMSPM_REPORT_\d{8}\.TXT_PART_\d+-\#-SCIPHERMSPM-\#-I.pif',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/setcipher/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/setcipher/set_cipher/;
                        $cname_new =~ s/timesduring/times_during/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-SCIPHERMSPM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct ASSPROM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_ASSPROM_REPORT_\d{8}\.TXT_PART_\d+-\#-ASSPROM-\#-I-\#-ASSPROM_AGGR-\#-A.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/withSWITCH/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/withSWITCH/with_SWITCH/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-ASSPROM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct SMSFAX Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_SMSFAX_\d{8}\.TXT_PART_\d+-\#-SMSFAX-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/usedby/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/usedby/used_by/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-SMSFAX',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct DTRM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_DTRM_REPORT_\d{8}\.TXT_PART_\d+-\#-DTRM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/devicesnum/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/devicesnum/devices_num/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-DTRM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct SCCPPM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_SCCPPM_REPORT_\d{8}\.TXT_PART_\d+-\#-SCCPPM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/routingfailure/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/routingfailure/routing_failure/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-SCCPPM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct SCCPAM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_SCCPAM_REPORT_\d{8}\.TXT_PART_\d+-\#-SCCPAM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/oflocal/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/oflocal/of_local/;
                        $cname_new =~ s/unavailabilityall/unavailability_all/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-SCCPAM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct AINTSPEM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_AINTSPEM_REPORT_\d{8}\.TXT_PART_\d+-\#-AINTSPEM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/Protocolerror/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/Protocolerror/Protocol_error/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-AINTSPEM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct MAPSPETM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_MAPSPETM_REPORT_\d{8}\.TXT_PART_\d+-\#-MAPSPETM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/ofForwarding/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/ofForwarding/of_Forwarding/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-MAPSPETM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct BSCRM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_BSCRM_REPORT_\d{8}\.TXT_PART_\d+-\#-BSCRM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/ofconfusion/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/ofconfusion/of_confusion/;
                        $cname_new =~ s/messageat/message_at/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-BSCRM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct TRMBCT, DESTDMBOD, ITOFCTM, FTOICTM, ITOMCTM, MTOICTM, ICSUBTOOPCTM and ITOICTM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_TRMBCT_REPORT_\d{8}\.TXT_PART_\d+-\#-TRMBCT-\#-I.pif',
					'\w+_DESTDMBOD_REPORT_\d{8}\.TXT_PART_\d+-\#-DESTDMBOD-\#-I.pif',
					'\w+_ITOFCTM_REPORT_\d{8}\.TXT_PART_\d+-\#-ITOFCTM-\#-I.pif',
					'\w+_FTOICTM_REPORT_\d{8}\.TXT_PART_\d+-\#-FTOICTM-\#-I.pif',
					'\w+_ITOMCTM_REPORT_\d{8}\.TXT_PART_\d+-\#-ITOMCTM-\#-I.pif',
					'\w+_MTOICTM_REPORT_\d{8}\.TXT_PART_\d+-\#-MTOICTM-\#-I.pif',
					'\w+_ICSUBTOOPCTM_REPORT_\d{8}\.TXT_PART_\d+-\#-ICSUBTOOPCTM-\#-I.pif',
					'\w+_ITOICTM_REPORT_\d{8}\.TXT_PART_\d+-\#-ITOICTM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/Answeredtraffic/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/Answeredtraffic/Answered_traffic/;
                        $cname_new =~ s/mobileplaced/mobile_placed/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct INCM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_INCM_REPORT_\d{8}\.TXT_PART_\d+-\#-INCM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/Messagesof/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/Messagesof/Messages_of/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-INCM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct CANSW Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_CANSW_REPORT_05032007.TXT_PART_\d+-\#-CANSW-\#-I.pif',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/Answeredratio/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/Answeredratio/Answered_ratio/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-CANSW',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct INSM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_INSM_REPORT_\d{8}\.TXT_PART_\d+-\#-INSM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/theTCAP/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/theTCAP/the_TCAP/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ-INSM',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Reconstruct INSMOM and MAPINSM Report',
        INPUT_FILE_DESCRIPTION  => [
					'\w+_INSMOM_REPORT_\d{8}\.TXT_PART_\d+-\#-INSMOM-\#-I.pif',
					'\w+_MAPINSM_REPORT_\d{8}\.TXT_PART_\d+-\#-MAPINSM-\#-I.pif'
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                foreach my $cname (grep {/ofreceived/} keys %{$d_ref}) {
                        my $cname_new = $cname;
                        $cname_new =~ s/ofreceived/of_received_/;
                        $d_ref->{$cname_new} = $d_ref->{$cname};
                        delete $d_ref->{$cname};
                }

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},

{
	'RULE_TYPE'              => 'PIF_2_OUTPUT',
	'RULE_DESC'              => 'OUTPUT ALL INPUT FILES',
	'INPUT_FILE_DESCRIPTION' => [
					'\w+_AUTHSM_REPORT_\d{8}\.TXT_PART_\d+-\#-AUTHSM-\#-I.pif',
					'\w+_CHECKIMEIPM_REPORT_\d{8}\.TXT_PART_\d+-\#-CHECKIMEIPM-\#-I.pif',
					'\w+_CPROM_REPORT_05032007.TXT_PART_\d+-\#-CPROM-\#-I.pif',
					'\w+_DEST_REPORT_\d{8}\.TXT_PART_\d+-\#-DEST-\#-I.pif',
					'\w+_DROP_REPORT_05032007.TXT_PART_\d+-\#-DROP-\#-I.pif',
					'\w+_FAIL_REPORT_\d{8}\.TXT_PART_\d+-\#-FAIL-\#-I.pif',
					'\w+_HOMOCELL_REPORT_\d{8}\.TXT_PART_\d+-\#-HOMOCELL-\#-I.pif',
					'\w+_INCM_REPORT_\d{8}\.TXT_PART_\d+-\#-INCM-\#-I.pif',
					'\w+_INEM_REPORT_\d{8}\.TXT_PART_\d+-\#-INEM-\#-I.pif',
					'\w+_IWF10CHM_REPORT_\d{8}\.TXT_PART_\d+-\#-IWF10CHM-\#-I.pif',
					'\w+_MAPCSPEM_REPORT_\d{8}\.TXT_PART_\d+-\#-MAPCSPEM-\#-I.pif',
					'\w+_MSCBTM_REPORT_\d{8}\.TXT_PART_\d+-\#-MSCBTM-\#-I.pif',
					'\w+_MTCCM_REPORT_05032007.TXT_PART_\d+-\#-MTCCM-\#-I.pif',
					'\w+_OBSCHM_REPORT_\d{8}\.TXT_PART_\d+-\#-OBSCHM-\#-I.pif',
					'\w+_SCCPURM_REPORT_\d{8}\.TXT_PART_\d+-\#-SCCPURM-\#-I.pif',
					'\w+_SRFRM_REPORT_\d{8}\.TXT_PART_\d+-\#-SRFRM-\#-I.pif',
					'\w+_TCAPAM_REPORT_\d{8}\.TXT_PART_\d+-\#-TCAPAM-\#-I.pif',
					'\w+_TCAPCURM_REPORT_\d{8}\.TXT_PART_\d+-\#-TCAPCURM-\#-I.pif',
					'\w+_TCAPMAM_REPORT_\d{8}\.TXT_PART_\d+-\#-TCAPMAM-\#-I.pif',
					'\w+_TCAPSLPPM_REPORT_\d{8}\.TXT_PART_\d+-\#-TCAPSLPPM-\#-I.pif',
					'\w+_TCAPTSLPM_REPORT_\d{8}\.TXT_PART_\d+-\#-TCAPTSLPM-\#-I.pif',
					'\w+_TCAPCSLPM_REPORT_\d{8}\.TXT_PART_\d+-\#-TCAPCSLPM-\#-I.pif',
					'\w+_CPXX_REPORT_\d{8}\.TXT_PART_\d+-\#-CPXX-\#-I.pif',
					'\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-\#-MSC-\#-I.pif',
					'\w+_LUPAG,PAGING_REPORT_\d{8}.TXT_PART_\d+-\#-LUPAG-\#-I.pif',
					'\w+_LSETM_REPORT_\d{8}\.TXT_PART_\d+-\#-LSETM-\#-I.pif',
					'\w+_DSPM_REPORT_\d{8}\.TXT_PART_\d+-\#-DSPM-\#-I.pif',
					'\w+_SRFRM_REPORT_\d{8}\.TXT_PART_\d+-\#-SRFRM-\#-I.pif',
					'\w+_QOS_REPORT_\d{8}\.TXT_PART_\d+-\#-QOS-\#-I.pif',  #to also include INTCRDM files.
					'\w+_VLRTM_REPORT_\d{8}\.TXT_PART_\d+-\#-VLRTM-\#-I.pif',
					'^\w+_ASSPROM_REPORT_\d{8}\.TXT_PART_\d+-#-ASSPROM-#-I\.pif',
				    ],
	'PRODUCE_PIF'            => 0,
	'PRODUCE_LIF'            => 'True',
},


#-------------------------------------------------------------------------------
);  

#-------------------------------------------------------------------------------

sub postparser_config {
	return \@rules;
}

1;
