#-------------------------------------------------------------------------------
# @(#) common-modules/Example/EngineConfig.pm common-modules_r3.1.1.8:cset.001773:5:5 08/16/05 @(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# My Vendor Interface
# 
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();
use AudLog;

#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = 
    (
     {
         RULE_TYPE => 'Generic_ASCII',
         RULE_DESC => 'HUAWEI NSS V61 DATA',
         INPUT_FILE_DESCRIPTION => [ 
				'^\w+_\w+_\d{8}\.TXT$' ,
				],
         INPUT_DIR_DEPTH => 0,
         ORDER_OF_FILES => 'OLDEST_FIRST',

	 OUTPUT_BLOCK_NAME          => 'HUAWEI_NSS',
	 DEFAULT_NULL_VALUE         => '',
	 UPPERCASE_COUNTERS         => 0,
	 FILENAME_HEADER_FIELDS      => {
		FILENAME	=> '(.*)',
		ORIGINAL_FILENAME	=> '(.*)',
		MSC_NAME	=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
		NODEID		=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
		MSC_ID		=> '^([A-Za-z0-9]+)_\w+_\d{8}\.TXT$',
		BLOCKNAME	=> '^[A-Za-z0-9]+_(\w+)_\d{8}\.TXT$',
	 },

	 HEADER_INFO_TO_KEY_PIF_FILENAME => ['FILENAME'],

         # HEADER_LINE_PROCESSING and DATA_LINE_PROCESSING has
         # two sub-configuration entries,
         # LINE_DESCRIPTION - A regular expression to match the line pattern
         # LINE_PROCESSING  - A perl sub-routine to process the line 
         # Arguments:
         #     $rule_obj	- the current rule object
         #     $line_sref	- the current line reference
         #     $h_href		- the hash reference of the header record
         #     $d_href		- the hash reference of the data record
         # 
         # Returns: 
         #     'NOMATCH'	- Proceed with next match
         #     'NEXTLINE'	- Match and processed, continue next line
         #     'GODATA'		- End of header record, goto data processing on the current line
         #     'GOHEADER'	- End of data record, goto header processing on the current line
         #     'WRITEPIF'	- End of data record, goto header processing on the current line
         #     -1		- Failed, rename input file to '.bad' 
         #     -2		- Failed, do not rename input file to '.bad'
         HEADER_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\Time\ *\|',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				#%$h_href = ();
				%$d_href = ();
				if ($rule_obj->{OLD_FILENAME} ne $h_href->{ORIGINAL_FILENAME}) {
					$rule_obj->{OLD_FILENAME} = $h_href->{ORIGINAL_FILENAME};
					LogMess("Now processing $h_href->{ORIGINAL_FILENAME}",5);
					$rule_obj->{BLOCK_COUNTER} = 0;
				}
				$rule_obj->{BLOCK_COUNTER}++;	
				$h_href->{FILENAME} = $h_href->{ORIGINAL_FILENAME} . "_PART_" . $rule_obj->{BLOCK_COUNTER};
				return 'GODATA';
			},
		},
					],
	 DATA_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\Time\ *\|',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;
				$line =~ s/\ +\|/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ s/\.//g;
				$line =~ s/\,//g;
				$line =~ s/\-/_/g;
				$line =~ s/_$//g;
				$line =~ s/\(\%\)//g;
				$line =~ s/\(Times\)//g;
				$line =~ s/\(Last\ Result\)\ //g;
				$line =~ s/\(PCS\)//g;
				$line =~ s/\(Erl\)//g;
				$line =~ s/\(Second\)//g;
				$line =~ s/\(Item\)//g;
				$line =~ s/\(//g;
				$line =~ s/\)//g;
				$line =~ s/\ /_/g;
				$line =~ s/\&//g;
				$line =~ s/\://g;
				$line =~ s/\//_/g;
				$line =~ s/\_+/\_/g;
				my @dref_keys = split /\|/, $line;
				$rule_obj->{COUNTER_NAMES} = \@dref_keys;
				return 'NEXTLINE';
			},
		},
	 	{
			LINE_DESCRIPTION => '^\w+
*$',
			LINE_PROCESSING  => sub {
				return 'GOHEADER';
			},
		},
	 	{
			LINE_DESCRIPTION => '^\d{4}-\d{2}-\d{2}\ \d{2}:\d{2}',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;
				$line =~ s/\ +\|/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ tr/\n\t -~//cd;
				$line =~ s/\ *
*$//g;
				$line =~ s/\ *\=\ */\=/g;
				$line =~ s/\ *\,\ */\,/g;
				$line =~ s/(\d+)\,(\d+)/$1\.$2/g;
				$line =~ s/(\d+)\%/$1/g;
				$line =~ s/\ /_/g;
				$line =~ s/\_\_+//g;
				$line =~ s/\<NULL\>//g;
				$line =~ s/\*//g;
				$line =~ s/\(//g;
				$line =~ s/\)//g;
				my @counter_value = split /\|/, $line;
				foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
					$d_href->{$counter_name} = shift @counter_value;
				}
				return 'WRITEPIF';
			},
		},
	],
	 HEADER_DATA_RECORD_PROCESSING => sub {
		my ($blk_name_ref, $h_ref, $d_ref) = @_;

		# Set block name
		#$h_ref->{BLOCKNAME} =~ s/\_REPORT(_\d+)*//g;
		$h_ref->{BLOCKNAME} =~ s/\_REPORT//g;
		$h_ref->{BLOCKNAME} =~ s/TGRP1/TGRP/g;
		$$blk_name_ref = $h_ref->{BLOCKNAME};

		# Set date and time
		if ($d_ref->{Time} =~ /(\d{4}-\d{2}-\d{2})_(\d{2}:\d{2})/) {
			$d_ref->{START_DATE} = $1;
			$d_ref->{START_TIME} = $2;
			$d_ref->{GP} = $d_ref->{Period} * 60;
			delete $d_ref->{Time};
			delete $d_ref->{Period};
		}

		# Split up Objects
		if (exists($d_ref->{Object})){
			my @object_name = split /\,/, $d_ref->{Object};
			foreach my $oname_ori (@object_name) {
				if ($oname_ori =~ /(\w+)\.*\=(.*)/) {
					$d_ref->{$1} = $2;
				}
			}
			$d_ref->{Object} =~ s/\.//g;
			$d_ref->{Object} =~ tr/\=\,/_\//;
		}
		# Rename some counters
		if ($h_ref->{BLOCKNAME} eq "SCCPPM" ) {
			foreach my $oname_ori (keys %$d_ref) {
				if ($oname_ori =~ /^Route_Failure_/) {
					my $oname_new = $oname_ori;
					$oname_new =~ s/^Route_Failure_//g;
					$d_ref->{$oname_new} = $d_ref->{$oname_ori};
					delete $d_ref->{$oname_ori};
				}
			}
		}
		if ($h_ref->{BLOCKNAME} eq "FAIL" || $h_ref->{BLOCKNAME} eq "COMBCDOTM") {
			foreach my $oname_ori (keys %$d_ref) {
				if ($oname_ori =~ /^0_/) {
					my $oname_new = $oname_ori;
					$oname_new =~ s/^0_/Zero_/g;
					$d_ref->{$oname_new} = $d_ref->{$oname_ori};
					delete $d_ref->{$oname_ori};
				}
			}
		}
		if ($h_ref->{BLOCKNAME} eq "C7LL") {
			foreach my $oname_ori (keys %$d_ref) {
				if ($oname_ori =~ /^2/) {
					my $oname_new = $oname_ori;
					$oname_new =~ s/^2/Two_/g;
					$d_ref->{$oname_new} = $d_ref->{$oname_ori};
					delete $d_ref->{$oname_ori};
				}
			}
		}
		if ($h_ref->{BLOCKNAME} eq "INEM" ) {
			foreach my $oname_ori (keys %$d_ref) {
				if ($oname_ori =~ /^.*_DP\d+$/) {
					my $oname_new = $oname_ori;
					$oname_new =~ s/_DP\d+$//g;
					$d_ref->{$oname_new} = $d_ref->{$oname_ori};
					delete $d_ref->{$oname_ori};
				}
			}
		}
		if ($h_ref->{BLOCKNAME} eq "COMBCDOTM" ) {
			if (!exists($d_ref->{Call_Number}) || $d_ref->{Call_Number} =~ /^$/){
				$d_ref->{Call_Number} = "NULL";
			}
			if (!exists($d_ref->{Outgoing_Trunk_Office_Direction_No}) || $d_ref->{Outgoing_Trunk_Office_Direction_No} =~ /^$/){
				$d_ref->{Outgoing_Trunk_Office_Direction_No} = "NULL";
			}
			if (!exists($d_ref->{Called_Number}) || $d_ref->{Called_Number} =~ /^$/){
				$d_ref->{Called_Number} = "NULL";
			}
			if (!exists($d_ref->{Call_Source_Office_Direction_No}) || $d_ref->{Call_Source_Office_Direction_No} =~ /^$/){
				$d_ref->{Call_Source_Office_Direction_No} = "NULL";
			}
			if (!exists($d_ref->{Call_Type}) || $d_ref->{Call_Type} =~ /^$/){
				$d_ref->{Call_Type} = "NULL";
			}
		}

		return 0;
	 },
 },

     {
         RULE_TYPE => 'Generic_ASCII',
         RULE_DESC => 'HUAWEI NSS V61 HIERARCHY',
         INPUT_FILE_DESCRIPTION => [ 
				'^\w+\.DISP\w*\.TXT$' ,
				],
         INPUT_DIR_DEPTH => 0,
         ORDER_OF_FILES => 'OLDEST_FIRST',

	 OUTPUT_BLOCK_NAME          => 'DISP',
	 DEFAULT_NULL_VALUE         => '',
	 UPPERCASE_COUNTERS         => 0,
	 FILENAME_HEADER_FIELDS      => {
		FILENAME	=> '(.*)',
		MSC_NAME	=> '^([A-Za-z0-9]+)\.DISP\w*\.TXT$',
		MSC_ID		=> '^([A-Za-z0-9]+)\.DISP\w*\.TXT$',
		NODEID		=> '^([A-Za-z0-9]+)\.DISP\w*\.TXT$',
		OLD_BLOCKNAME	=> '^[A-Za-z0-9]+\.(DISP\w*)\.TXT$',
	 },

	 HEADER_INFO_TO_KEY_PIF_FILENAME => ['FILENAME','BLOCKNAME'],

         # HEADER_LINE_PROCESSING and DATA_LINE_PROCESSING has
         # two sub-configuration entries,
         # LINE_DESCRIPTION - A regular expression to match the line pattern
         # LINE_PROCESSING  - A perl sub-routine to process the line 
         # Arguments:
         #     $rule_obj	- the current rule object
         #     $line_sref	- the current line reference
         #     $h_href		- the hash reference of the header record
         #     $d_href		- the hash reference of the data record
         # 
         # Returns: 
         #     'NOMATCH'	- Proceed with next match
         #     'NEXTLINE'	- Match and processed, continue next line
         #     'GODATA'		- End of header record, goto data processing on the current line
         #     'GOHEADER'	- End of data record, goto header processing on the current line
         #     'WRITEPIF'	- End of data record, goto header processing on the current line
         #     -1		- Failed, rename input file to '.bad' 
         #     -2		- Failed, do not rename input file to '.bad'
         HEADER_LINE_PROCESSING     => [
	 	{
			LINE_DESCRIPTION => '^\-+
*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
				#%$h_href = ();
				%$d_href = ();
				$rule_obj->{BLOCK_COUNTER}++;	
				$h_href->{BLOCKNAME} = $h_href->{OLD_BLOCKNAME} . "_" . $rule_obj->{BLOCK_COUNTER};
				return 'GODATA';
			},
		},
	 ],
	 DATA_LINE_PROCESSING     => [
	 	{
			# FILE HEADER
			LINE_DESCRIPTION => 'Frame\ No\..*Slot\ No\.',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;
				$line =~ s/\ \ +/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ s/\.//g;
				$line =~ s/\-/_/g;
				$line =~ s/\ /_/g;
				$line =~ s/_$//g;
				my @dref_keys = split /\|/, $line;
				$rule_obj->{COUNTER_NAMES} = \@dref_keys;
				return 'NEXTLINE';
			},
		},
	 	{
			# FILE HEADER
			LINE_DESCRIPTION => 'Office\ Direction\ No\.',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;
				$line =~ s/\ \ +/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ s/^\ +//g;
				$line =~ s/\.//g;
				$line =~ s/\-/_/g;
				$line =~ s/\ /_/g;
				$line =~ s/_$//g;
				my @dref_keys = split /\|/, $line;
				$rule_obj->{COUNTER_NAMES} = \@dref_keys;
				return 'NEXTLINE';
			},
		},
	 	{
			LINE_DESCRIPTION => '^\-+
*$',
			LINE_PROCESSING  => sub {
				return 'NEXTLINE';
			},
		},
	 	{
			LINE_DESCRIPTION => '^
*$',
			LINE_PROCESSING  => sub {
				return 'NEXTLINE';
			},
		},
	 	{
			LINE_DESCRIPTION => '^\(Number\ of\ results\ \=\ ',
			LINE_PROCESSING  => sub {
				return 'GOHEADER';
			},
		},
	 	{
			LINE_DESCRIPTION => '^.*$',
			LINE_PROCESSING  => sub {
				my ($rule_obj, $line_sref, $h_href, $d_href) = @_;
			        my $line = $$line_sref;
				$line =~ s/\ \ +/|/g;
				$line =~ s/
//g;
				$line =~ s/^\ *//g;
				$line =~ s/\ /_/g;
				if ($line =~ /^\w+\|\w+\|\w+/) {
					my @counter_value = split /\|/, $line;
					foreach my $counter_name (@{$rule_obj->{COUNTER_NAMES}}) {
						$d_href->{$counter_name} = shift @counter_value;
					}
					return 'WRITEPIF';
				}
				else {
					return 'NEXTLINE';
				}
			},
		},
	 ],
	 #HEADER_DATA_RECORD_PROCESSING => 


 	},
);  


sub engine_config {
    return \@rules;
}

1;
