#
#-------------------------------------------------------------------------------
# @(#) common-modules/Example/UserConfig.pm common-modules_r3.1.1.8:cset.001773:5:5 08/16/05 @(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# My Vendor Interface
#
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.
#
package UserConfig;

# Company Name: 

@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

#use diagnostics;
use strict;
use Exporter ();

#-------------------------------------------------------------------------------

my @rules = (
#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------

{
	'RULE_TYPE'              => 'JOIN',
	'RULE_DESC'              => 'Join DISP files',
	'INPUT_FILE_DESCRIPTION' => ['^(.*)\.DISP\.TXT-#-.*-#-I\.pif'],
	'COUNTERS_TO_JOIN_ON'	 => ['FILENAME', 'Frame_No', 'Slot_No','Board_Internal_Link_No'],
	'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ['FILENAME'],
	'OUTPUT_BLOCK_NAME'	 => 'DISP',
	'OUTPUT_FILENAME_START'	 => 'DISP',
	'PRODUCE_PIF'            => 'True',
	'PRODUCE_LIF'            => 0,
},
{
	'RULE_TYPE'              => 'JOIN',
	'RULE_DESC'              => 'Join DISPTG files',
	'INPUT_FILE_DESCRIPTION' => ['^(.*)\.DISPTG\.TXT-#-.*-#-I\.pif'],
	'COUNTERS_TO_JOIN_ON'	 => ['FILENAME', 'Office_Direction_No'],
	'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ['FILENAME'],
	'OUTPUT_BLOCK_NAME'	 => 'DISPTG',
	'OUTPUT_FILENAME_START'	 => 'DISPTG',
	'PRODUCE_PIF'            => 'True',
	'PRODUCE_LIF'            => 0,
},
{
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert DISP information into files',
        INPUT_FILE_DESCRIPTION  => [
                '^(\w+)_C7LL_REPORT_\d{8}\.TXT_PART_\d+-#-C7LL-#-I\.pif$',
        ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD     =>      [],
        NAMES_USED_TO_ID_DATA_RECORD    => ['Module_No', 'Link_No'],
        INFO_FILE_DESCRIPTION   => ['^DISP-#-(\w+)\.DISP\.TXT-#-\d+-#-J\.pif'],
        HEADER_NAMES_USED_TO_ID_INFORMATION     => [],
        NAMES_USED_TO_ID_INFORMATION    => ['Module_No', 'Link_No'],
        OUTPUT_FILENAME_START   => 'II',
        #ONLY_INSERT => ['NodeB_Id'],
        WRITE_DATA_LINE => 'True',
        REDUNDANT_DATA_COUNTERS         => [],
        PRODUCE_PIF     => 'True',
        PRODUCE_LIF     => 0,

},
{
        RULE_TYPE               => 'INFOINSERT',
        RULE_DESC               => 'Insert DISPTG information into files',
        INPUT_FILE_DESCRIPTION  => [
                '^(\w+)_TGRP_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP-#-I\.pif$',
        ],
        HEADER_NAMES_USED_TO_ID_DATA_RECORD     =>      [],
        NAMES_USED_TO_ID_DATA_RECORD    => ['Office_Direction_No'],
        INFO_FILE_DESCRIPTION   => ['^DISPTG-#-(\w+)\.DISPTG\.TXT-#-\d+-#-J\.pif'],
        HEADER_NAMES_USED_TO_ID_INFORMATION     => [],
        NAMES_USED_TO_ID_INFORMATION    => ['Office_Direction_No'],
        OUTPUT_FILENAME_START   => 'II',
        #ONLY_INSERT => ['NodeB_Id'],
        WRITE_DATA_LINE => 'True',
        REDUNDANT_DATA_COUNTERS         => [],
        PRODUCE_PIF     => 0,
        PRODUCE_LIF     => 'True',

},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing Link_Set_No',
        INPUT_FILE_DESCRIPTION  => [
                                        '^II-#-\w+_C7LL_REPORT_\d{8}\.TXT_PART_\d+-#-C7LL-#-I-#-S\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

                $d_ref->{Link_Set_No} = $d_ref->{Frame_No} + $d_ref->{Slot_No} + $d_ref->{Board_Internal_Link_No};

                return 0;
        },
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
	RULE_TYPE => 'FILE_SPLIT_BY_COUNTERS',
	RULE_DESC => 'Split up MSC_REPORT files based on traffic type',
	INPUT_FILE_DESCRIPTION => ['^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I\.pif$'],
	SPLIT_CNAMES => {
		ORG	=> [ '^\w+_ORG$' ],
		INT	=> [ '^\w+_INT$' ],
		ORGOEX	=> [ '^\w+_ORGOEX$' ],
		IEX	=> [ '^\w+_IEX$' ],
		IEXTE	=> [ '^\w+_IEXTE$' ],
		TE	=> [ '^\w+_TE$' ],
		TRA	=> [ '^\w+_TRA$' ],
		OEX	=> [ '^\w+_OEX$' ],
			},
	ONLY_INSERT	=> ['ORIGINAL_FILENAME', 'NODEID', 'MSC_ID','Credibility','GP','START_TIME','START_DATE'],
	PRODUCE_PIF => 'True',
	OUTPUT_BLOCK_NAME => 'TRAFTYPE',
	OUTPUT_FORMAT => 0,

},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE OEX',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-OEX-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_OEX$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_OEX$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'OEX';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE TRA',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-TRA-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_TRA$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_TRA$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'TRA';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE TE',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-TE-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_TE$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_TE$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'TE';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE IEXTE',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-IEXTE-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_IEXTE$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_IEXTE$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'IEXTE';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE IEX',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-IEX-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_IEX$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_IEX$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'IEX';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE ORGOEX',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-ORGOEX-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_ORGOEX$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_ORGOEX$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'ORGOEX';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE INT',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-INT-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_INT$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_INT$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'INT';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
        RULE_TYPE               => 'PERLIZE',
        RULE_DESC               => 'Constructing TRAFTYPE ORG',
        INPUT_FILE_DESCRIPTION  => [
					'^\w+_MSC_REPORT_\d{8}\.TXT_PART_\d+-#-MSC-#-I-#-ORG-#-FSC\.pif$',
                                ],
        DATA_COUNTERS_OP        => sub {
                my $d_ref = shift;

		foreach my $cname (grep {/_ORG$/} keys %{$d_ref}) {
			my $cname_new = $cname;
			$cname_new =~ s/_ORG$//;
			$d_ref->{$cname_new} = $d_ref->{$cname};
			delete $d_ref->{$cname};
		}
		$d_ref->{'Traffic_type'} = 'ORG';

                return 0;
        },
	OUTPUT_BLOCK_NAME	=> 'MSC_TRAFTYPE',
        FILENAME_SUFFIX         => 'PZ',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
},
{
	RULE_TYPE               => 'ACCUMULATE',
	RULE_DESC               => 'Aggregrate CELLTD files to MSC level',
	INPUT_FILE_DESCRIPTION => [
                			'^\w+_CELLTD_REPORT_\d{8}\.TXT_PART_\d+-#-CELLTD-#-I\.pif$',
					],
	COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
	OUTPUT_BLOCK_NAME       => 'CELLTD_AGGR',
	PRODUCE_PIF             => 0,
	OUTPUT_FORMAT           => 'LIF_Writer',
	NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME)],
	REDUNDANT_DATA_COUNTERS         => [],
},
{
	RULE_TYPE               => 'ACCUMULATE',
	RULE_DESC               => 'Aggregrate ASSPROM files to MSC level',
	INPUT_FILE_DESCRIPTION => [
                			'^\w+_ASSPROM_REPORT_\d{8}\.TXT_PART_\d+-#-ASSPROM-#-I\.pif$',
					],
	COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
	OUTPUT_BLOCK_NAME       => 'ASSPROM_AGGR',
	PRODUCE_PIF             => 0,
	OUTPUT_FORMAT           => 'LIF_Writer',
	NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME)],
	REDUNDANT_DATA_COUNTERS         => [],
},
{
	RULE_TYPE               => 'ACCUMULATE',
	RULE_DESC               => 'Aggregrate LUPAG files to MSC level',
	INPUT_FILE_DESCRIPTION => [
                			'^\w+_LUPAG_REPORT_\d{8}\.TXT_PART_\d+-#-LUPAG-#-I\.pif$',
					],
	COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
	OUTPUT_BLOCK_NAME       => 'LUPAG_AGGR',
	PRODUCE_PIF             => 'True',
	PRODUCE_LIF             => 0,
	NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME)],
	REDUNDANT_DATA_COUNTERS         => [],
},
{
	RULE_TYPE               => 'ACCUMULATE',
	RULE_DESC               => 'Aggregrate OBSCHM files to MSC level',
	INPUT_FILE_DESCRIPTION => [
                			'^\w+_OBSCHM_REPORT_\d{8}\.TXT_PART_\d+-#-OBSCHM-#-I\.pif$',
					],
	COUNTERS_TO_SORT_ON     => [qw(MSC_ID START_DATE START_TIME)],
	OUTPUT_BLOCK_NAME       => 'OBSCHM_AGGR',
	PRODUCE_PIF             => 0,
	OUTPUT_FORMAT           => 'LIF_Writer',
	NON_ADDITIVE_COUNTERS   => [qw(GP START_DATE Reliability START_TIME MSC_ID MSC_NAME ORIGINAL_FILENAME)],
	REDUNDANT_DATA_COUNTERS         => [],
},
{
	RULE_TYPE              => 'PIF_2_OUTPUT',
	RULE_DESC              => 'OUTPUT LUPAG2 FILES',
	INPUT_FILE_DESCRIPTION => [ '^\w+_LUPAG_REPORT_\d{8}\.TXT_PART_2-#-LUPAG-#-I\.pif$'],
	OUTPUT_BLOCK_NAME       => 'LUPAG2',
	PRODUCE_PIF            => 0,
	PRODUCE_LIF            => 'True',
},
{
	RULE_TYPE              => 'PIF_2_OUTPUT',
	RULE_DESC              => 'OUTPUT LUPAG AGGR FILES',
	INPUT_FILE_DESCRIPTION => [ '^\w+_LUPAG_REPORT_\d{8}\.TXT_PART_1-#-LUPAG-#-I-#-LUPAG_AGGR-#-A\.pif$'],
	OUTPUT_BLOCK_NAME       => 'LUPAG_AGGR',
	PRODUCE_PIF            => 0,
	PRODUCE_LIF            => 'True',
},
{
	RULE_TYPE              => 'PIF_2_OUTPUT',
	RULE_DESC              => 'OUTPUT LUPAG2_AGGR FILES',
	INPUT_FILE_DESCRIPTION => [ '^\w+_LUPAG_REPORT_\d{8}\.TXT_PART_2-#-LUPAG-#-I-#-LUPAG_AGGR-#-A\.pif$'],
	OUTPUT_BLOCK_NAME       => 'LUPAG2_AGGR',
	PRODUCE_PIF            => 0,
	PRODUCE_LIF            => 'True',
},
{
	'RULE_TYPE'              => 'PIF_REMOVE',
	'RULE_DESC'              => 'REMOVE unneeded files',
	'INPUT_FILE_DESCRIPTION' => [
					'^.*\.DISPTG\.TXT-#-.*-#-I\.pif',
					'^.*\.DISP\.TXT-#-.*-#-I\.pif',
                			'^\w+_TGRP_REPORT_\d{8}\.TXT_PART_\d+-#-TGRP-#-I\.pif$',
                			'^\w+_C7LL_REPORT_\d{8}\.TXT_PART_\d+-#-C7LL-#-I\.pif$',
                                        '^II-#-\w+_C7LL_REPORT_\d{8}\.TXT_PART_\d+-#-C7LL-#-I-#-S\.pif$',
					'^\w+_LUPAG_REPORT_\d{8}\.TXT_PART_2-#-LUPAG-#-I\.pif$',
					],
	PRODUCE_PIF             => 'True',
	PRODUCE_LIF             => 0,
},
{
	'RULE_TYPE'              => 'PIF_2_OUTPUT',
	'RULE_DESC'              => 'OUTPUT ALL FILES',
	'INPUT_FILE_DESCRIPTION' => ['^.*-#-I\.pif'],
	'PRODUCE_PIF'            => 0,
	'PRODUCE_LIF'            => 'True',
},


#-------------------------------------------------------------------------------
);  

#-------------------------------------------------------------------------------

sub postparser_config {
	return \@rules;
}

1;
